@@ -19,11 +19,28 @@
  */
 
 /*
- * $RCSfile: global.h,v $
- * $Revision: 1.2 $
- * $Date: 2010/02/25 01:10:04 $
+ * $RCSfile$
+ * $Revision$
+ * $Date$
  */
 
+#ifndef _GLOBAL_H_
+#define _GLOBAL_H_
+
+/* Return Code */
+#define SUCCESS		0
+#define ERROR		-1
+
+/* String Code */
+#define STR_JIS        "ISO-2022-JP"
+#define STR_EUC        "EUC-JP"
+#define STR_SJIS       "SJIS"
+#define STR_UTF8       "UTF-8"
+#define STR_UTF8_LEN   sizeof(STR_UTF8)
+#define STR_JIS_LEN    sizeof(STR_JIS)
+#define STR_EUC_LEN    sizeof(STR_EUC)
+#define STR_SJIS_LEN   sizeof(STR_SJIS)
+
 #define MALLOC_ERROR -2
 
 #ifdef DEBUG
@@ -35,3 +52,5 @@
 #define	DEBUGLOG(a...)
 
 #endif
+
+#endif /* _GLOBAL_H_ */
