@@ -1,7 +1,7 @@
 /*
  * samma
  *
- * Copyright (C) 2006,2007,2008 DesigNET, INC.
+ * Copyright (C) 2006,2007,2008,2011 DesigNET, INC.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: mailzip.h,v $
- * $Revision: 1.8 $
- * $Date: 2011/07/29 03:03:03 $
+ * $Revision: 1.9 $
+ * $Date: 2011/12/28 03:22:21 $
  */
 
 #define IDENT   		"samma"
@@ -35,11 +35,15 @@
 #define ZIPCONV			0
 #define NOZIPCONV		1
 #define XHEADER			"X-SaMMA-Enc"
+#define XHEADER_YES		"YES"
+#define LOOP_CHECK		"yes"
 #define MAX_ARGS		4
 #define MLFICLOSE		0
 #define MLFIABORT		1
 #define BEFOR_RCPTCHECK		0
 #define AFTER_RCPTCHECK		1
+#define ENABLE_AUTOBCC		0
+#define DISABLE_AUTOBCC		1
 #define CODE_INVALID_FILENAME	"550"
 #define XCODE_INVALID_FILENAME	"5.7.1"
 #define MESSAGE_INVALID_FILENAME "Your attachment filename may include invalid encoding. Please rename attachment file and resend."
@@ -89,6 +93,10 @@ struct mlfiPriv
     struct rcptinfo *mlfi_passlist;
     struct rcptinfo *mlfi_rdmpasslist;
     int		    mlfi_rcptcheck;
+    int		    mlfi_encstatus;
+    int		    mlfi_bccoption;
+    struct rcptaddr *mlfi_savebcc;
+    int             mlfi_whitelist;
 };
 
 pthread_t              child;
